% clc
clear all


%system
system.sqn=7/2;% spin quantum number
system.interactions={1,0,'z','e',1.5};  % resonance frequency in GHz in the AWG frame
system.D=0.1;   % ZFS parameters in GHz
system.E=0.01;  
system.phi=0;   % orientation of the crystal
system.theta=pi;%
system.init_state='-z';    % initial state

options.det_op={'-z1,2','-z2,3','-z3,4','-z4,5','-z5,6','-z6,7','-z7,8'}; % transition selective detection operators
options.LO=8;  % frequency of the local oscillator, to upconvert to lab frame
options.labframe=0; % tells SPIDYAN whether to simulate in lab frame or not

sequence.tp=[2000 2000];  % length of the pulses in ns [1st_pulse 2nd_pulse]
sequence.nu1=[4 4];  % microwave amplitude of the pulses [1st_pulse 2nd_pulse]
sequence.frq={[0.8 1.43] [2.2 1.57]}; % initial and final frequencies for linear chirps
sequence.detection = [1 1];
sequence.t_rise=30; % rise time, for both pulses

% processing
[experiment,options] = triple(sequence, options);   % builds pulses

[system, state, options]=setup(system,options);   % builds system

[state, detected_signal, experiment, options, tables]=homerun(state,system,experiment, options, []); % propagates system

figure(1),clf
title('Polarization on detected transitions')
hold on
box on
plot(experiment.taxis(1:10:end),real(detected_signal.sf(:,(1:10:end))))
legend(options.det_op,'Location','NorthWest')
xlabel('t [ns]')
ylabel('<S_q>')
xlim([0 sum(sequence.tp)])
ylim([-4 7])