% simulation frames
clear all
% definition of spin system
system.sqn = 1/2;        % spin quantum number
system.interactions = {1,0,'z','e',1.0};  % interaction table for the spin Hamiltonian
system.init_state = '-z'; % initial state of the spin system

% pulse sequence
rectangular.tp = 10;    % pulse length in ns
rectangular.frq = 1;    % microwave freqency in GHz
rectangular.beta = pi;  % alternative to nu1
rectangular.t_rise=0;   % rise time in ns
rectangular.type={'rectangular'};   % type of pulse
rectangular.detection = 1;

% options
options.relaxation = 0;   % relaxation is switched off
options.LO = 8;           % frequency of the LO in GHz
options.det_op = {'-z','y'};     %detection operators, -Sz and Sx
options.down_conversion = 1; % switch downconversion on or off

%% simulation in the lab frame %%%%%%%%%%%

options.labframe = 1;     % lab frame simulation is on
% options.awg.s_rate = 40;  % can be switched on to improve accuracy

[LFsystem,state0,options] = setup(system,options); % processing of system

[experiment,options] = triple(rectangular,options); % processing of pulse

[~, LFsignal] =  homerun(state0, LFsystem, experiment, options, []); % propagation

figure(1)
plot(LFsignal.t,real(LFsignal.dc))
xlabel('t [ns]')
ylabel('<S_i>')

%% simulation in the LO frame %%%%%%%%%%%
clear options
options.relaxation = 0;   % relaxation is switched off
options.LO = 8;           % frequency of the LO in GHz
options.det_op = {'-z','y'};     %detection operators, -Sz and Sx
options.labframe = 0;     % lab frame simulation is off
options.down_conversion = 1; % switch downconversion on or off

[LOsystem,state0,options] = setup(system,options); % processing of system

[experiment,options] = triple(rectangular,options); % processing of pulse

[~, LOsignal] =  homerun(state0, LOsystem, experiment, options, []); % propagation

figure(2)
plot(LOsignal.t,real(LOsignal.sf))
xlabel('t [ns]')
ylabel('<S_i>')

%% downconverted signal

figure(3)
plot(LOsignal.t,real(LOsignal.dc))
xlabel('t [ns]')
ylabel('<S_i>')

